@@ -161,7 +161,6 @@ public class InstallFrame extends JFrame {
         platformComboBox.addItem("solaris-amd64");
         platformComboBox.addItem("linux-intel");
         platformComboBox.addItem("linux-x86_64");
-        platformComboBox.addItem("osx-x86_64");
         platformComboBox.setSelectedIndex(0);
         platformComboBox.addActionListener(new
               InstallFrame_platformComboBox_actionAdapter(this));
@@ -177,9 +176,6 @@ public class InstallFrame extends JFrame {
         else if (BP.platform == "linux-x86_64" ) {
              platformComboBox.setSelectedIndex(3);
         }
-        else if (BP.platform == "osx-x86_64" ) {
-             platformComboBox.setSelectedIndex(4);
-        }
         else {
             platformComboBox.setSelectedIndex(2);
         }
